@@ -5,7 +5,7 @@ import os
 from mopidy import config, exceptions, ext
 
 
-__version__ = '1.4.0'
+__version__ = '2.0.0'
 
 
 class Extension(ext.Extension):
@@ -20,15 +20,15 @@ class Extension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(Extension, self).get_config_schema()
-        schema['desktop_file'] = config.Path()
+        schema['desktop_file'] = config.Deprecated()
         schema['bus_type'] = config.String(choices=['session', 'system'])
         return schema
 
     def validate_environment(self):
         try:
-            import dbus  # noqa
+            import pydbus  # noqa
         except ImportError as e:
-            raise exceptions.ExtensionError('dbus library not found', e)
+            raise exceptions.ExtensionError('pydbus library not found', e)
 
     def setup(self, registry):
         from .frontend import MprisFrontend
